@@ -8,7 +8,7 @@
    opsi-nagios-connector is part of the desktop management solution opsi
    (open pc server integration) http://www.opsi.org
 
-   Copyright (C) 2010 uib GmbH
+   Copyright (C) 2010-2015 uib GmbH
 
    http://www.uib.de/
 
@@ -18,24 +18,25 @@
    @author: Erol Ueluekmen <e.ueluekmen@uib.de>
 """
 
+import datetime
 import base64
 import json
+import os
 import re
+import time
 from hashlib import md5
 from twisted.internet import defer
-import resource as pyresource
 from twisted.conch.ssh import keys
 
-from OPSI.web2 import http, resource, stream
-from OPSI.Backend.BackendManager import BackendManager
+from OPSI.web2 import http, stream
 from OPSI.Service.Worker import WorkerOpsi
 from OPSI.Object import *
 from OPSI.System import getDiskSpaceUsage
+from OPSI.Types import OpsiAuthenticationError
 
 from OPSI.Service.Resource import ResourceOpsi
-from OPSI.Logger import *
-from OPSI.Types import *
-import datetime
+from OPSI.Logger import LOG_INFO, Logger
+from OPSI.Types import forceList
 
 logger = Logger()
 
@@ -175,8 +176,10 @@ class WorkerOpsiconfdMonitoring(WorkerOpsi):
 		if self.query:
 			query = json.loads(self.query)
 			if not query.has_key("task"):
-				res["state"] = "3"
-				res["message"] = u"No task set, nothing to do"
+				res = {
+					"state": 3,
+					"message": u"No task set, nothing to do"
+				}
 				result.stream = stream.IByteStream(json.dumps(res).encode('utf-8'))
 				return result
 
@@ -354,7 +357,7 @@ class Monitoring(object):
 		else:
 			clientObj = clientObj[0]
 		if not clientObj.lastSeen:
-			state = _WARNING
+			state = self._WARNING
 			message += u"opsi-client: '%s' never seen, please check opsi-client-agent installation on client. " % clientId
 		else:
 			lastSeen = clientObj.lastSeen.split("-")
@@ -369,7 +372,7 @@ class Monitoring(object):
 				lastSeenDate = datetime.date(year,month,day)
 				delta = today - lastSeenDate
 			elif state == self._OK:
-				state = _WARNING
+				state = self._WARNING
 				message += u"opsi-client: '%s' never seen, please check opsi-client-agent installation on client. " % clientId
 
 			if delta.days >= 30:
@@ -820,7 +823,7 @@ class Monitoring(object):
 				errorrate = int(rpcerrors)*100//int(rpcs)
 
 			if (errorrate > errors[0] ):
-				messages.append(u'RPC errors over 20\%')
+				message.append(u'RPC errors over 20\%')
 				state = self._CRITICAL
 			elif (errorrate > errors[1]):
 				message.append(u'RPC errors over 10\%')
